Module llvm_profparser::summary[][src]

Structs

Enums

The type of the profile summary

Constants

The amount to scale cutoffs by to go back to a more readable percentile

These are the default cutoffs for profile summary entries. Without cutoffs specified manually llvm-profdata and associated tools will use these. These numbers represent percentiles of counts in the profile data scaled by 10_000_000 (divide by these scales to go back to percentiles)