Module llvm_profparser::util

source ·

Functions

  • Parses a list of paths - this is currently only used in parsing the sections in an instrumented object file, and due to CWD joining is different to the other string parsing implemented